<h1 align="center"> Gitscrpy </h1>

***



* `A python library to scrape github.`
* `Simple to use syntax`
* `Install using pip`

<h2 id="install">Install</h2>

```python
pip install gitscrpy


```

<h2 id="install">Run</h2>

```python


```